/*
 * libemail-engine.h
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef LIBEMAIL_ENGINE_H
#define LIBEMAIL_ENGINE_H

#define __LIBEMAIL_ENGINE_H_INSIDE__

#include <libemail-engine/camel-null-store.h>
#include <libemail-engine/e-mail-engine-enums.h>
#include <libemail-engine/e-mail-engine-enumtypes.h>
#include <libemail-engine/e-mail-folder-utils.h>
#include <libemail-engine/e-mail-junk-filter.h>
#include <libemail-engine/e-mail-session.h>
#include <libemail-engine/e-mail-session-utils.h>
#include <libemail-engine/e-mail-store-utils.h>
#include <libemail-engine/e-mail-utils.h>
#include <libemail-engine/em-filter-folder-element.h>
#include <libemail-engine/em-vfolder-context.h>
#include <libemail-engine/em-vfolder-rule.h>
#include <libemail-engine/mail-config.h>
#include <libemail-engine/mail-folder-cache.h>
#include <libemail-engine/mail-mt.h>
#include <libemail-engine/mail-ops.h>
#include <libemail-engine/mail-tools.h>
#include <libemail-engine/mail-vfolder.h>

#undef __LIBEMAIL_ENGINE_H_INSIDE__

#endif /* LIBEMAIL_ENGINE_H */

